@@ -92,3 +92,55 @@ class GraphQLView(View):
         response.set_data(json.dumps(response_data))
 
         return response
+
+
+class AsyncGraphQLView(GraphQLView):
+    async def dispatch_request(self):
+        method = request.method
+        content_type = request.content_type or ""
+
+        if "application/json" in content_type:
+            data: dict = request.json  # type:ignore[assignment]
+        elif content_type.startswith("multipart/form-data"):
+            operations = json.loads(request.form.get("operations", "{}"))
+            files_map = json.loads(request.form.get("map", "{}"))
+
+            data = replace_placeholders_with_files(operations, files_map, request.files)
+        elif method == "GET" and request.args:
+            data = parse_query_params(request.args.to_dict())
+        elif method == "GET" and should_render_graphiql(self.graphiql, request):
+            template = render_graphiql_page()
+
+            return self.render_template(template=template)
+        else:
+            return Response("Unsupported Media Type", 415)
+
+        try:
+            request_data = parse_request_data(data)
+        except MissingQueryError:
+            return Response("No valid query was provided for the request", 400)
+
+        response = Response(status=200, content_type="application/json")
+        context = self.get_context(response)
+
+        allowed_operation_types = OperationType.from_http(method)
+
+        if not self.allow_queries_via_get and method == "GET":
+            allowed_operation_types = allowed_operation_types - {OperationType.QUERY}
+
+        try:
+            result = await self.schema.execute(
+                request_data.query,
+                variable_values=request_data.variables,
+                context_value=context,
+                operation_name=request_data.operation_name,
+                root_value=self.get_root_value(),
+                allowed_operation_types=allowed_operation_types,
+            )
+        except InvalidOperationTypeError as e:
+            return Response(e.as_http_error_reason(method), 400)
+
+        response_data = self.process_result(result)
+        response.set_data(json.dumps(response_data))
+
+        return response
