@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+import dataclasses
+import sys
 from typing import (
     Any,
     Callable,
@@ -34,7 +36,9 @@ from graphql import (
     Undefined,
     ValueNode,
 )
+from graphql.language.directive_locations import DirectiveLocation
 
+from strawberry.annotation import StrawberryAnnotation
 from strawberry.arguments import StrawberryArgument, convert_arguments
 from strawberry.custom_scalar import ScalarDefinition, ScalarWrapper
 from strawberry.directive import StrawberryDirective
@@ -49,6 +53,7 @@ from strawberry.lazy_type import LazyType
 from strawberry.private import is_private
 from strawberry.schema.config import StrawberryConfig
 from strawberry.schema.types.scalar import _make_scalar_type
+from strawberry.schema_directive import StrawberrySchemaDirective
 from strawberry.type import StrawberryList, StrawberryOptional, StrawberryType
 from strawberry.types.info import Info
 from strawberry.types.types import TypeDefinition
@@ -152,6 +157,42 @@ class GraphQLCoreConverter:
             description=directive.description,
         )
 
+    def from_schema_directive(self, directive: Any) -> GraphQLDirective:
+        cls = directive.__class__
+        strawberry_directive = cast(
+            StrawberrySchemaDirective, cls.__strawberry_directive__
+        )
+        module = sys.modules[cls.__module__]
+
+        args: Dict[str, GraphQLArgument] = {}
+        for field in strawberry_directive.fields:
+            default = field.default
+            if default == dataclasses.MISSING:
+                default = UNSET
+
+            name = self.config.name_converter.get_graphql_name(field)
+            args[name] = self.from_argument(
+                StrawberryArgument(
+                    python_name=field.python_name or field.name,
+                    graphql_name=None,
+                    type_annotation=StrawberryAnnotation(
+                        annotation=field.type,
+                        namespace=module.__dict__,
+                    ),
+                    default=default,
+                )
+            )
+
+        return GraphQLDirective(
+            name=self.config.name_converter.from_directive(strawberry_directive),
+            locations=[
+                DirectiveLocation(loc.value) for loc in strawberry_directive.locations
+            ],
+            is_repeatable=False,
+            args=args,
+            description=strawberry_directive.description,
+        )
+
     def from_field(self, field: StrawberryField) -> GraphQLField:
         field_type = cast(GraphQLOutputType, self.from_maybe_optional(field.type))
 
