@@ -1,16 +1,6 @@
 import dataclasses
 import warnings
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Generic,
-    List,
-    Optional,
-    TypeVar,
-    Union,
-    cast,
-)
+from typing import TYPE_CHECKING, Any, Dict, Generic, List, Optional, TypeVar, Union
 
 from backports.cached_property import cached_property
 
@@ -51,8 +41,8 @@ class Info(Generic[ContextType, RootValueType]):
             "`info.field_nodes` is deprecated, use `selected_fields` instead",
             DeprecationWarning,
         )
-        # TODO: remove cast when GraphQL-core > 3.2.0 is release
-        return cast(List[FieldNode], self._raw_info.field_nodes)
+
+        return self._raw_info.field_nodes
 
     @cached_property
     def selected_fields(self) -> List[Selection]:
